pub trait GetPgMetadataCache {
// Required method
fn get_metadata_cache(&mut self) -> &mut PgMetadataCache;
}Available on crate features
i-implement-a-third-party-backend-and-opt-into-breaking-changes and postgres_backend only.Expand description
Gets the PgMetadataCache for a Connection<Backend=Pg>
so that the lookup of user defined types, or types which come from an extension can be cached.
Implementing this trait for a Connection<Backend=Pg> will cause PgMetadataLookup to be auto implemented.
Required Methods
Sourcefn get_metadata_cache(&mut self) -> &mut PgMetadataCache
fn get_metadata_cache(&mut self) -> &mut PgMetadataCache
Get the PgMetadataCache
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl GetPgMetadataCache for PgConnection
Available on crate feature
postgres only.